@@ -199,7 +199,12 @@ void test_p2p_create_destroy_ctx::test_xfer(send_func_t send, size_t length,
     ASSERT_EQ(cuDeviceGet(&device, 0), CUDA_SUCCESS);
 
     CUcontext ctx;
+#if CUDA_VERSION >= 12050
+    CUctxCreateParams ctx_create_params = {};
+    ASSERT_EQ(cuCtxCreate_v4(&ctx, &ctx_create_params, 0, device), CUDA_SUCCESS);
+#else
     ASSERT_EQ(cuCtxCreate(&ctx, 0, device), CUDA_SUCCESS);
+#endif
     uct_p2p_rma_test::test_xfer(send, length, flags, mem_type);
     EXPECT_EQ(cuCtxDestroy(ctx), CUDA_SUCCESS);
 }
@@ -576,6 +581,10 @@ public:
 protected:
     void init() override
     {
+        if (!mem_buffer::is_mem_type_supported(UCS_MEMORY_TYPE_CUDA)) {
+            UCS_TEST_SKIP_R("CUDA is not supported");
+        }
+
         ASSERT_EQ(cudaGetDeviceCount(&m_num_devices), cudaSuccess);
         if (m_num_devices < 2) {
             UCS_TEST_SKIP_R("less than two cuda devices available");
